@@ -31,7 +31,6 @@ class AllowedValue(CloudFormationLintRule):
     def check_value(self, value, path, property_name, **kwargs):
         """Check Value"""
         matches = []
-
         allowed_value_specs = kwargs.get("value_specs", {}).get("AllowedValues", {})
 
         if allowed_value_specs:
@@ -62,15 +61,24 @@ class AllowedValue(CloudFormationLintRule):
                         property_type = (
                             property_specs.get("Properties").get(prop).get("Type")
                         )
+                        value_type_details = (
+                            RESOURCE_SPECS.get(cfn.regions[0])
+                            .get("ValueTypes")
+                            .get(value_type, {})
+                        )
+                        if value_type_details == "CACHED":
+                            value_type_details = (
+                                RESOURCE_SPECS.get("us-east-1")
+                                .get("ValueTypes")
+                                .get(value_type, {})
+                            )
                         matches.extend(
                             cfn.check_value(
                                 p_value,
                                 prop,
                                 p_path,
                                 check_value=self.check_value,
-                                value_specs=RESOURCE_SPECS.get(cfn.regions[0])
-                                .get("ValueTypes")
-                                .get(value_type, {}),
+                                value_specs=value_type_details,
                                 cfn=cfn,
                                 property_type=property_type,
                                 property_name=prop,
